@@ -30,15 +30,12 @@
 
 #include <krandom.h>
 
-#include <QtCore/QDateTime>
-#include <QtCore/QDebug>
-#include <QtCore/QSharedPointer>
-#include <QtCore/QByteArray>
-#include <QtCore/QFile>
-#include <QtCore/QAtomicInt>
-#include <QtCore/QList>
-#include <QtCore/QMutex>
-#include <QtCore/QMutexLocker>
+#include <QDebug>
+#include <QSharedPointer>
+#include <QByteArray>
+#include <QFile>
+#include <QAtomicInt>
+#include <QMutex>
 #include <QDir>
 
 #include <sys/types.h>
@@ -873,7 +870,7 @@ struct SharedMemory {
             break;
         }
 
-        qSort(table, table + indexTableSize(), compareFunction);
+        std::sort(table, table + indexTableSize(), compareFunction);
 
         // Least recently used entries will be in the front.
         // Start killing until we have room.
@@ -970,7 +967,7 @@ struct SharedMemory {
 
 // The per-instance private data, such as map size, whether
 // attached or not, pointer to shared memory, etc.
-class KSharedDataCache::Private
+class Q_DECL_HIDDEN KSharedDataCache::Private
 {
 public:
     Private(const QString &name,
@@ -979,7 +976,7 @@ public:
            )
         : m_cacheName(name)
         , shm(nullptr)
-        , m_lock(nullptr)
+        , m_lock()
         , m_mapSize(0)
         , m_defaultCacheSize(defaultCacheSize)
         , m_expectedItemSize(expectedItemSize)
@@ -1299,6 +1296,9 @@ public:
             }
         }
 
+        CacheLocker(const CacheLocker &) = delete;
+        CacheLocker &operator=(const CacheLocker &) = delete;
+
         bool failed() const
         {
             return !d || d->shm == nullptr;
